@@ -10,6 +10,7 @@ import (
 
 	"github.com/cli/cli/v2/api"
 	fd "github.com/cli/cli/v2/internal/featuredetection"
+	"github.com/cli/cli/v2/internal/gh"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	shared "github.com/cli/cli/v2/pkg/cmd/pr/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
@@ -149,10 +150,10 @@ func TestNewCmdEdit(t *testing.T) {
 			output: EditOptions{
 				SelectorArg: "23",
 				Editable: shared.Editable{
-					Reviewers: shared.EditableSlice{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{
 						Add:    []string{"monalisa", "owner/core"},
 						Edited: true,
-					},
+					}},
 				},
 			},
 			wantsErr: false,
@@ -163,10 +164,10 @@ func TestNewCmdEdit(t *testing.T) {
 			output: EditOptions{
 				SelectorArg: "23",
 				Editable: shared.Editable{
-					Reviewers: shared.EditableSlice{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{
 						Remove: []string{"monalisa", "owner/core"},
 						Edited: true,
-					},
+					}},
 				},
 			},
 			wantsErr: false,
@@ -354,7 +355,7 @@ func Test_editRun(t *testing.T) {
 	tests := []struct {
 		name      string
 		input     *EditOptions
-		httpStubs func(*httpmock.Registry)
+		httpStubs func(*testing.T, *httpmock.Registry)
 		stdout    string
 		stderr    string
 	}{
@@ -380,11 +381,11 @@ func Test_editRun(t *testing.T) {
 						Value:  "base-branch-name",
 						Edited: true,
 					},
-					Reviewers: shared.EditableSlice{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{
 						Add:    []string{"OWNER/core", "OWNER/external", "monalisa", "hubot"},
 						Remove: []string{"dependabot"},
 						Edited: true,
-					},
+					}},
 					Assignees: shared.EditableAssignees{
 						EditableSlice: shared.EditableSlice{
 							Add:    []string{"monalisa", "hubot"},
@@ -411,11 +412,13 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// Non-interactive with Add/Remove doesn't need reviewers/assignees metadata
+				// REST API accepts logins and team slugs directly
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: false, teamReviewers: false, assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockRequestReviewsByLogin(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockProjectV2ItemUpdate(reg)
 			},
@@ -469,8 +472,8 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, true)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockPullRequestUpdateLabels(reg)
@@ -483,8 +486,19 @@ func Test_editRun(t *testing.T) {
 			input: &EditOptions{
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
-				Finder: shared.NewMockFinder("123", &api.PullRequest{
+				Finder: shared.NewMockFinder("123", &api.PullRequest{ // include existing reviewers so removal logic triggers
 					URL: "https://github.com/OWNER/REPO/pull/123",
+					ReviewRequests: api.ReviewRequests{Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "core", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "external", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "monalisa"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "hubot"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "dependabot"}},
+					}},
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: false,
 				Editable: shared.Editable{
@@ -500,10 +514,11 @@ func Test_editRun(t *testing.T) {
 						Value:  "base-branch-name",
 						Edited: true,
 					},
-					Reviewers: shared.EditableSlice{
-						Remove: []string{"OWNER/core", "OWNER/external", "monalisa", "hubot", "dependabot"},
-						Edited: true,
-					},
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{
+						Default: []string{"OWNER/core", "OWNER/external", "monalisa", "hubot", "dependabot"},
+						Remove:  []string{"OWNER/core", "OWNER/external", "monalisa", "hubot", "dependabot"},
+						Edited:  true,
+					}},
 					Assignees: shared.EditableAssignees{
 						EditableSlice: shared.EditableSlice{
 							Add:    []string{"monalisa", "hubot"},
@@ -530,16 +545,166 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// Non-interactive with Remove doesn't need reviewers metadata
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: false, teamReviewers: false, assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockRequestReviewsByLogin(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockProjectV2ItemUpdate(reg)
 			},
 			stdout: "https://github.com/OWNER/REPO/pull/123\n",
 		},
+		{
+			name: "remove all reviewers sends empty slices to mutation",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder: shared.NewMockFinder("123", &api.PullRequest{
+					URL: "https://github.com/OWNER/REPO/pull/123",
+					ReviewRequests: api.ReviewRequests{
+						Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+							{
+								RequestedReviewer: api.RequestedReviewer{
+									TypeName: "Team",
+									Slug:     "core",
+									Organization: struct {
+										Login string `json:"login"`
+									}{Login: "OWNER"},
+								},
+							},
+							{
+								RequestedReviewer: api.RequestedReviewer{
+									TypeName: "User",
+									Login:    "monalisa",
+								},
+							},
+						},
+					},
+				}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{
+						Default: []string{"OWNER/core", "monalisa"},
+						Remove:  []string{"OWNER/core", "monalisa"},
+						Edited:  true,
+					}},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{})
+				mockPullRequestUpdate(reg)
+				reg.Register(
+					httpmock.GraphQL(`mutation RequestReviewsByLogin\b`),
+					httpmock.GraphQLMutation(`
+					{ "data": { "requestReviewsByLogin": { "clientMutationId": "" } } }`,
+						func(inputs map[string]interface{}) {
+							// Verify that empty slices are sent to properly clear all reviewer types
+							require.Equal(t, []interface{}{}, inputs["userLogins"], "userLogins should be an empty slice")
+							require.Equal(t, []interface{}{}, inputs["botLogins"], "botLogins should be an empty slice")
+							require.Equal(t, []interface{}{}, inputs["teamSlugs"], "teamSlugs should be an empty slice")
+							require.Equal(t, false, inputs["union"], "union should be false for replace mode")
+						}),
+				)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		// Conditional team fetching cases
+		{
+			name: "non-interactive add only user reviewers skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder:      shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123"}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{Add: []string{"monalisa", "hubot"}, Edited: true}},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// Non-interactive with Add/Remove doesn't need reviewer metadata
+				mockRepoMetadata(reg, mockRepoMetadataOptions{})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockRequestReviewsByLogin(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "non-interactive add contains team reviewers skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder:      shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123"}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{Add: []string{"monalisa", "OWNER/core"}, Edited: true}},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// Non-interactive with Add/Remove doesn't need reviewer metadata
+				mockRepoMetadata(reg, mockRepoMetadataOptions{})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockRequestReviewsByLogin(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "non-interactive reviewers remove contains team skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder: shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123", ReviewRequests: api.ReviewRequests{Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+					{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "core", Organization: struct {
+						Login string `json:"login"`
+					}{Login: "OWNER"}}},
+					{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "monalisa"}},
+				}}}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{Remove: []string{"monalisa", "OWNER/core"}, Edited: true}},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// Non-interactive with Add/Remove doesn't need reviewer metadata
+				mockRepoMetadata(reg, mockRepoMetadataOptions{})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockRequestReviewsByLogin(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "non-interactive mutate reviewers with no change to existing team reviewers skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder:      shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123"}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableReviewers{EditableSlice: shared.EditableSlice{Add: []string{"monalisa"}, Remove: []string{"hubot"}, Default: []string{"OWNER/core"}, Edited: true}},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// Non-interactive with Add/Remove doesn't need reviewer metadata
+				mockRepoMetadata(reg, mockRepoMetadataOptions{})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockRequestReviewsByLogin(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
 		{
 			name: "interactive",
 			input: &EditOptions{
@@ -565,6 +730,16 @@ func Test_editRun(t *testing.T) {
 						e.Body.Value = "new body"
 						e.Reviewers.Value = []string{"monalisa", "hubot", "OWNER/core", "OWNER/external"}
 						e.Assignees.Value = []string{"monalisa", "hubot"}
+						// Populate metadata to simulate what searchFunc would do during prompting
+						e.Metadata.AssignableActors = []api.AssignableActor{
+							api.NewAssignableBot("HUBOTID", "hubot"),
+							api.NewAssignableUser("MONAID", "monalisa", "Mona Display Name"),
+						}
+						// Populate team metadata for reviewer search
+						e.Metadata.Teams = []api.OrgTeam{
+							{ID: "COREID", Slug: "core"},
+							{ID: "EXTERNALID", Slug: "external"},
+						}
 						e.Labels.Value = []string{"feature", "TODO", "bug"}
 						e.Labels.Add = []string{"feature", "TODO", "bug"}
 						e.Labels.Remove = []string{"docs"}
@@ -576,11 +751,13 @@ func Test_editRun(t *testing.T) {
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// With search functions enabled, we don't fetch reviewers/assignees metadata
+				// (searchFunc handles dynamic fetching, metadata populated in test mock)
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: false, teamReviewers: false, assignees: false, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockRequestReviewsByLogin(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockProjectV2ItemUpdate(reg)
 			},
@@ -608,7 +785,13 @@ func Test_editRun(t *testing.T) {
 					editFields: func(e *shared.Editable, _ string) error {
 						e.Title.Value = "new title"
 						e.Body.Value = "new body"
-						e.Assignees.Value = []string{"monalisa", "hubot"}
+						// When ActorAssignees is enabled, the interactive flow returns display names (or logins for non-users)
+						e.Assignees.Value = []string{"monalisa (Mona Display Name)", "hubot"}
+						// Populate metadata to simulate what searchFunc would do during prompting
+						e.Metadata.AssignableActors = []api.AssignableActor{
+							api.NewAssignableBot("HUBOTID", "hubot"),
+							api.NewAssignableUser("MONAID", "monalisa", "Mona Display Name"),
+						}
 						e.Labels.Value = []string{"feature", "TODO", "bug"}
 						e.Labels.Add = []string{"feature", "TODO", "bug"}
 						e.Labels.Remove = []string{"docs"}
@@ -620,8 +803,10 @@ func Test_editRun(t *testing.T) {
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, true)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// interactive but reviewers not chosen; need everything except reviewers/teams
+				// assignees: false because searchFunc handles dynamic fetching (metadata populated in test mock)
+				mockRepoMetadata(reg, mockRepoMetadataOptions{assignees: false, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockPullRequestUpdateLabels(reg)
@@ -634,8 +819,19 @@ func Test_editRun(t *testing.T) {
 			input: &EditOptions{
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
-				Finder: shared.NewMockFinder("123", &api.PullRequest{
+				Finder: shared.NewMockFinder("123", &api.PullRequest{ // include existing reviewers
 					URL: "https://github.com/OWNER/REPO/pull/123",
+					ReviewRequests: api.ReviewRequests{Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "core", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "external", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "monalisa"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "hubot"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "dependabot"}},
+					}},
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: true,
 				Surveyor: testSurveyor{
@@ -654,6 +850,16 @@ func Test_editRun(t *testing.T) {
 						e.Body.Value = "new body"
 						e.Reviewers.Remove = []string{"monalisa", "hubot", "OWNER/core", "OWNER/external", "dependabot"}
 						e.Assignees.Value = []string{"monalisa", "hubot"}
+						// Populate metadata to simulate what searchFunc would do during prompting
+						e.Metadata.AssignableActors = []api.AssignableActor{
+							api.NewAssignableBot("HUBOTID", "hubot"),
+							api.NewAssignableUser("MONAID", "monalisa", "Mona Display Name"),
+						}
+						// Populate team metadata for reviewer search
+						e.Metadata.Teams = []api.OrgTeam{
+							{ID: "COREID", Slug: "core"},
+							{ID: "EXTERNALID", Slug: "external"},
+						}
 						e.Labels.Value = []string{"feature", "TODO", "bug"}
 						e.Labels.Add = []string{"feature", "TODO", "bug"}
 						e.Labels.Remove = []string{"docs"}
@@ -665,10 +871,11 @@ func Test_editRun(t *testing.T) {
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// With search functions enabled, we don't fetch reviewers/assignees metadata
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: false, teamReviewers: false, assignees: false, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockRequestReviewsByLogin(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockProjectV2ItemUpdate(reg)
@@ -704,26 +911,20 @@ func Test_editRun(t *testing.T) {
 						require.Equal(t, []string{"hubot"}, e.Assignees.Default)
 						require.Equal(t, []string{"hubot"}, e.Assignees.DefaultLogins)
 
-						// Adding MonaLisa as PR assignee, should preserve hubot.
-						e.Assignees.Value = []string{"hubot", "MonaLisa (Mona Display Name)"}
+						// Adding monalisa as PR assignee, should preserve hubot.
+						e.Assignees.Value = []string{"hubot", "monalisa (Mona Display Name)"}
+						// Populate metadata to simulate what searchFunc would do during prompting
+						e.Metadata.AssignableActors = []api.AssignableActor{
+							api.NewAssignableBot("HUBOTID", "hubot"),
+							api.NewAssignableUser("MONAID", "monalisa", "Mona Display Name"),
+						}
 						return nil
 					},
 				},
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				reg.Register(
-					httpmock.GraphQL(`query RepositoryAssignableActors\b`),
-					httpmock.StringResponse(`
-					{ "data": { "repository": { "suggestedActors": {
-						"nodes": [
-							{ "login": "hubot", "id": "HUBOTID", "__typename": "Bot" },
-							{ "login": "MonaLisa", "id": "MONAID", "name": "Mona Display Name", "__typename": "User" }
-						],
-						"pageInfo": { "hasNextPage": false }
-					} } } }
-					`))
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
 				mockPullRequestUpdate(reg)
 				reg.Register(
 					httpmock.GraphQL(`mutation ReplaceActorsForAssignable\b`),
@@ -759,7 +960,7 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
 				// Notice there is no call to mockReplaceActorsForAssignable()
 				// and no GraphQL call to RepositoryAssignableActors below.
 				reg.Register(
@@ -768,7 +969,7 @@ func Test_editRun(t *testing.T) {
 					{ "data": { "repository": { "assignableUsers": {
 						"nodes": [
 							{ "login": "hubot", "id": "HUBOTID" },
-							{ "login": "MonaLisa", "id": "MONAID" }
+							{ "login": "monalisa", "id": "MONAID" }
 						],
 						"pageInfo": { "hasNextPage": false }
 					} } } }
@@ -777,6 +978,188 @@ func Test_editRun(t *testing.T) {
 			},
 			stdout: "https://github.com/OWNER/REPO/pull/123\n",
 		},
+		{
+			name: "interactive GHES uses legacy assignee flow without search",
+			input: &EditOptions{
+				Detector:    &fd.DisabledDetectorMock{},
+				SelectorArg: "123",
+				Finder: shared.NewMockFinder("123", &api.PullRequest{
+					URL: "https://github.com/OWNER/REPO/pull/123",
+					Assignees: api.Assignees{
+						Nodes:      []api.GitHubUser{{Login: "octocat", ID: "OCTOID"}},
+						TotalCount: 1,
+					},
+				}, ghrepo.New("OWNER", "REPO")),
+				Interactive: true,
+				Surveyor: testSurveyor{
+					fieldsToEdit: func(e *shared.Editable) error {
+						e.Assignees.Edited = true
+						return nil
+					},
+					editFields: func(e *shared.Editable, _ string) error {
+						require.False(t, e.Assignees.ActorAssignees)
+						require.Nil(t, e.AssigneeSearchFunc)
+						require.Contains(t, e.Assignees.Options, "monalisa")
+						require.Contains(t, e.Assignees.Options, "hubot")
+
+						e.Assignees.Value = []string{"monalisa", "hubot"}
+						return nil
+					},
+				},
+				Fetcher:         testFetcher{},
+				EditorRetriever: testEditorRetriever{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Exclude(t, httpmock.GraphQL(`query RepositoryAssignableActors\b`))
+				reg.Register(
+					httpmock.GraphQL(`query RepositoryAssignableUsers\b`),
+					httpmock.StringResponse(`
+					{ "data": { "repository": { "assignableUsers": {
+						"nodes": [
+							{ "login": "hubot", "id": "HUBOTID" },
+							{ "login": "monalisa", "id": "MONAID" }
+						],
+						"pageInfo": { "hasNextPage": false }
+					} } } }
+					`))
+				reg.Exclude(t, httpmock.GraphQL(`mutation ReplaceActorsForAssignable\b`))
+				mockPullRequestUpdate(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "interactive GHES uses legacy reviewer flow without search",
+			input: &EditOptions{
+				Detector:    &fd.DisabledDetectorMock{},
+				SelectorArg: "123",
+				Finder: shared.NewMockFinder("123", &api.PullRequest{
+					URL: "https://github.com/OWNER/REPO/pull/123",
+					ReviewRequests: api.ReviewRequests{Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "octocat"}},
+					}},
+				}, ghrepo.New("OWNER", "REPO")),
+				Interactive: true,
+				Surveyor: testSurveyor{
+					fieldsToEdit: func(e *shared.Editable) error {
+						e.Reviewers.Edited = true
+						return nil
+					},
+					editFields: func(e *shared.Editable, _ string) error {
+						// Verify GHES uses legacy flow: ReviewerSearchFunc should be nil
+						require.Nil(t, e.ReviewerSearchFunc)
+						// Verify options are populated from fetched metadata
+						require.Contains(t, e.Reviewers.Options, "monalisa")
+						require.Contains(t, e.Reviewers.Options, "hubot")
+						require.Contains(t, e.Reviewers.Options, "OWNER/core")
+
+						e.Reviewers.Value = []string{"monalisa", "OWNER/core"}
+						return nil
+					},
+				},
+				Fetcher:         testFetcher{},
+				EditorRetriever: testEditorRetriever{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// GHES should NOT use the new SuggestedReviewerActors query
+				reg.Exclude(t, httpmock.GraphQL(`query SuggestedReviewerActors\b`))
+				// GHES should use legacy metadata fetch for reviewers (AssignableUsers, not Actors)
+				reg.Exclude(t, httpmock.GraphQL(`query RepositoryAssignableActors\b`))
+				reg.Register(
+					httpmock.GraphQL(`query RepositoryAssignableUsers\b`),
+					httpmock.StringResponse(`
+					{ "data": { "repository": { "assignableUsers": {
+						"nodes": [
+							{ "login": "hubot", "id": "HUBOTID" },
+							{ "login": "monalisa", "id": "MONAID" }
+						],
+						"pageInfo": { "hasNextPage": false }
+					} } } }
+					`))
+				// GHES should fetch teams for interactive reviewer editing
+				reg.Register(
+					httpmock.GraphQL(`query OrganizationTeamList\b`),
+					httpmock.StringResponse(`
+					{ "data": { "organization": { "teams": {
+						"nodes": [
+							{ "slug": "external", "id": "EXTERNALID" },
+							{ "slug": "core", "id": "COREID" }
+						],
+						"pageInfo": { "hasNextPage": false }
+					} } } }
+					`))
+				// Current user fetched for reviewers
+				reg.Register(
+					httpmock.GraphQL(`query UserCurrent\b`),
+					httpmock.StringResponse(`
+					{ "data": { "viewer": { "login": "monalisa" } } }
+					`))
+				mockPullRequestUpdate(reg)
+				mockPullRequestAddReviewers(reg)
+				mockPullRequestRemoveReviewers(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "non-interactive projects v1 unsupported doesn't fetch v1 metadata",
+			input: &EditOptions{
+				Detector:    &fd.DisabledDetectorMock{},
+				SelectorArg: "123",
+				Finder: shared.NewMockFinder("123", &api.PullRequest{
+					URL: "https://github.com/OWNER/REPO/pull/123",
+				}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Projects: shared.EditableProjects{
+						EditableSlice: shared.EditableSlice{
+							Add:    []string{"CleanupV2"},
+							Remove: []string{"RoadmapV2"},
+							Edited: true,
+						},
+					},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// Ensure v1 project queries are NOT made.
+				reg.Exclude(t, httpmock.GraphQL(`query RepositoryProjectList\b`))
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationProjectList\b`))
+				// Provide only v2 project metadata queries.
+				reg.Register(
+					httpmock.GraphQL(`query RepositoryProjectV2List\b`),
+					httpmock.StringResponse(`
+					{ "data": { "repository": { "projectsV2": {
+						"nodes": [
+							{ "title": "CleanupV2", "id": "CLEANUPV2ID" },
+							{ "title": "RoadmapV2", "id": "ROADMAPV2ID" }
+						],
+						"pageInfo": { "hasNextPage": false }
+					} } } }
+					`))
+				reg.Register(
+					httpmock.GraphQL(`query OrganizationProjectV2List\b`),
+					httpmock.StringResponse(`
+					{ "data": { "organization": { "projectsV2": {
+						"nodes": [
+							{ "title": "TriageV2", "id": "TRIAGEV2ID" }
+						],
+						"pageInfo": { "hasNextPage": false }
+					} } } }
+					`))
+				reg.Register(
+					httpmock.GraphQL(`query UserProjectV2List\b`),
+					httpmock.StringResponse(`
+					{ "data": { "viewer": { "projectsV2": {
+						"nodes": [
+							{ "title": "MonalisaV2", "id": "MONALISAV2ID" }
+						],
+						"pageInfo": { "hasNextPage": false }
+					} } } }
+					`))
+				mockProjectV2ItemUpdate(reg)
+				mockPullRequestUpdate(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -787,7 +1170,7 @@ func Test_editRun(t *testing.T) {
 
 			reg := &httpmock.Registry{}
 			defer reg.Verify(t)
-			tt.httpStubs(reg)
+			tt.httpStubs(t, reg)
 
 			httpClient := func() (*http.Client, error) { return &http.Client{Transport: reg}, nil }
 			baseRepo := func() (ghrepo.Interface, error) { return ghrepo.New("OWNER", "REPO"), nil }
@@ -804,21 +1187,34 @@ func Test_editRun(t *testing.T) {
 	}
 }
 
-func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryAssignableActors\b`),
-		httpmock.StringResponse(`
+type mockRepoMetadataOptions struct {
+	reviewers     bool
+	teamReviewers bool // reviewers must also be true for this to have an effect.
+	assignees     bool
+	labels        bool
+	projects      bool // includes both legacy (v1) and v2
+	milestones    bool
+}
+
+func mockRepoMetadata(reg *httpmock.Registry, opt mockRepoMetadataOptions) {
+	// Assignable actors (users/bots) are fetched when reviewers OR assignees edited with ActorAssignees enabled.
+	if opt.reviewers || opt.assignees {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryAssignableActors\b`),
+			httpmock.StringResponse(`
 			{ "data": { "repository": { "suggestedActors": {
 				"nodes": [
 					{ "login": "hubot", "id": "HUBOTID", "__typename": "Bot" },
-					{ "login": "MonaLisa", "id": "MONAID", "name": "Mona Display Name", "__typename": "User" }
+					{ "login": "monalisa", "id": "MONAID", "name": "Mona Display Name", "__typename": "User" }
 				],
 				"pageInfo": { "hasNextPage": false }
 			} } } }
 			`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryLabelList\b`),
-		httpmock.StringResponse(`
+	}
+	if opt.labels {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryLabelList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "labels": {
 			"nodes": [
 				{ "name": "feature", "id": "FEATUREID" },
@@ -829,9 +1225,11 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryMilestoneList\b`),
-		httpmock.StringResponse(`
+	}
+	if opt.milestones {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryMilestoneList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "milestones": {
 			"nodes": [
 				{ "title": "GA", "id": "GAID" },
@@ -840,9 +1238,11 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryProjectList\b`),
-		httpmock.StringResponse(`
+	}
+	if opt.projects {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryProjectList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "projects": {
 			"nodes": [
 				{ "name": "Cleanup", "id": "CLEANUPID" },
@@ -851,9 +1251,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query OrganizationProjectList\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query OrganizationProjectList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "organization": { "projects": {
 			"nodes": [
 				{ "name": "Triage", "id": "TRIAGEID" }
@@ -861,9 +1261,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryProjectV2List\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryProjectV2List\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "projectsV2": {
 			"nodes": [
 				{ "title": "CleanupV2", "id": "CLEANUPV2ID" },
@@ -872,9 +1272,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query OrganizationProjectV2List\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query OrganizationProjectV2List\b`),
+			httpmock.StringResponse(`
 		{ "data": { "organization": { "projectsV2": {
 			"nodes": [
 				{ "title": "TriageV2", "id": "TRIAGEV2ID" }
@@ -882,9 +1282,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query UserProjectV2List\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query UserProjectV2List\b`),
+			httpmock.StringResponse(`
 		{ "data": { "viewer": { "projectsV2": {
 			"nodes": [
 				{ "title": "MonalisaV2", "id": "MONALISAV2ID" }
@@ -892,7 +1292,8 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	if !skipReviewers {
+	}
+	if opt.teamReviewers && opt.reviewers { // teams only relevant if reviewers edited
 		reg.Register(
 			httpmock.GraphQL(`query OrganizationTeamList\b`),
 			httpmock.StringResponse(`
@@ -904,11 +1305,13 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
         "pageInfo": { "hasNextPage": false }
       } } } }
 		`))
+	}
+	if opt.reviewers { // Current user fetched only when reviewers requested
 		reg.Register(
 			httpmock.GraphQL(`query UserCurrent\b`),
 			httpmock.StringResponse(`
-		  { "data": { "viewer": { "login": "monalisa" } } }
-		`))
+	  { "data": { "viewer": { "login": "monalisa" } } }
+	`))
 	}
 }
 
@@ -927,12 +1330,29 @@ func mockPullRequestUpdateActorAssignees(reg *httpmock.Registry) {
 	)
 }
 
-func mockPullRequestReviewersUpdate(reg *httpmock.Registry) {
+func mockPullRequestAddReviewers(reg *httpmock.Registry) {
 	reg.Register(
-		httpmock.GraphQL(`mutation PullRequestUpdateRequestReviews\b`),
+		httpmock.REST("POST", "repos/OWNER/REPO/pulls/0/requested_reviewers"),
 		httpmock.StringResponse(`{}`))
 }
 
+func mockPullRequestRemoveReviewers(reg *httpmock.Registry) {
+	reg.Register(
+		httpmock.REST("DELETE", "repos/OWNER/REPO/pulls/0/requested_reviewers"),
+		httpmock.StringResponse(`{}`))
+}
+
+// mockRequestReviewsByLogin mocks the RequestReviewsByLogin GraphQL mutation
+// used on github.com when ActorAssignees is enabled.
+func mockRequestReviewsByLogin(reg *httpmock.Registry) {
+	reg.Register(
+		httpmock.GraphQL(`mutation RequestReviewsByLogin\b`),
+		httpmock.GraphQLMutation(`
+		{ "data": { "requestReviewsByLogin": { "clientMutationId": "" } } }`,
+			func(inputs map[string]interface{}) {}),
+	)
+}
+
 func mockPullRequestUpdateLabels(reg *httpmock.Registry) {
 	reg.Register(
 		httpmock.GraphQL(`mutation LabelAdd\b`),
@@ -959,8 +1379,8 @@ func mockProjectV2ItemUpdate(reg *httpmock.Registry) {
 
 type testFetcher struct{}
 
-func (f testFetcher) EditableOptionsFetch(client *api.Client, repo ghrepo.Interface, opts *shared.Editable) error {
-	return shared.FetchOptions(client, repo, opts)
+func (f testFetcher) EditableOptionsFetch(client *api.Client, repo ghrepo.Interface, opts *shared.Editable, projectsV1Support gh.ProjectsV1Support) error {
+	return shared.FetchOptions(client, repo, opts, projectsV1Support)
 }
 
 type testSurveyor struct {
