@@ -7,12 +7,15 @@ import (
 	"fmt"
 	"io"
 	"net/http"
+	"net/url"
 	"reflect"
 	"sort"
 	"strings"
+	"time"
 
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/api"
+	fd "github.com/cli/cli/v2/internal/featuredetection"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	"github.com/cli/cli/v2/pkg/cmd/workflow/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
@@ -25,6 +28,7 @@ type RunOptions struct {
 	HttpClient func() (*http.Client, error)
 	IO         *iostreams.IOStreams
 	BaseRepo   func() (ghrepo.Interface, error)
+	Detector   fd.Detector
 	Prompter   iprompter
 
 	Selector  string
@@ -53,18 +57,20 @@ func NewCmdRun(f *cmdutil.Factory, runF func(*RunOptions) error) *cobra.Command
 	cmd := &cobra.Command{
 		Use:   "run [<workflow-id> | <workflow-name>]",
 		Short: "Run a workflow by creating a workflow_dispatch event",
-		Long: heredoc.Doc(`
-			Create a workflow_dispatch event for a given workflow.
+		Long: heredoc.Docf(`
+			Create a %[1]sworkflow_dispatch%[1]s event for a given workflow.
 
 			This command will trigger GitHub Actions to run a given workflow file. The given workflow file must
-			support a workflow_dispatch 'on' trigger in order to be run in this way.
+			support an %[1]son.workflow_dispatch%[1]s trigger in order to be run in this way.
 
 			If the workflow file supports inputs, they can be specified in a few ways:
 
 			- Interactively
-			- via -f or -F flags
-			- As JSON, via STDIN
-    `),
+			- Via %[1]s-f/--raw-field%[1]s or %[1]s-F/--field%[1]s flags
+			- As JSON, via standard input
+
+			The created workflow run URL will be returned if available.
+		`, "`"),
 		Example: heredoc.Doc(`
 			# Have gh prompt you for what workflow you'd like to run and interactively collect inputs
 			$ gh workflow run
@@ -128,8 +134,8 @@ func NewCmdRun(f *cmdutil.Factory, runF func(*RunOptions) error) *cobra.Command
 			return runRun(opts)
 		},
 	}
-	cmd.Flags().StringVarP(&opts.Ref, "ref", "r", "", "The branch or tag name which contains the version of the workflow file you'd like to run")
-	cmd.Flags().StringArrayVarP(&opts.MagicFields, "field", "F", nil, "Add a string parameter in `key=value` format, respecting @ syntax")
+	cmd.Flags().StringVarP(&opts.Ref, "ref", "r", "", "Branch or tag name which contains the version of the workflow file you'd like to run")
+	cmd.Flags().StringArrayVarP(&opts.MagicFields, "field", "F", nil, "Add a string parameter in `key=value` format, respecting @ syntax (see \"gh help api\").")
 	cmd.Flags().StringArrayVarP(&opts.RawFields, "raw-field", "f", nil, "Add a string parameter in `key=value` format")
 	cmd.Flags().BoolVar(&opts.JSON, "json", false, "Read workflow inputs as JSON via STDIN")
 
@@ -217,7 +223,18 @@ func collectInputs(p iprompter, yamlContent []byte) (map[string]string, error) {
 
 	for _, input := range inputs {
 		var answer string
-		if input.Required {
+
+		if input.Type == "choice" {
+			name := input.Name
+			if input.Required {
+				name += " (required)"
+			}
+			selected, err := p.Select(name, input.Default, input.Options)
+			if err != nil {
+				return nil, err
+			}
+			answer = input.Options[selected]
+		} else if input.Required {
 			for answer == "" {
 				answer, err = p.Input(input.Name+" (required)", input.Default)
 				if err != nil {
@@ -234,7 +251,6 @@ func collectInputs(p iprompter, yamlContent []byte) (map[string]string, error) {
 
 		providedInputs[input.Name] = answer
 	}
-
 	return providedInputs, nil
 }
 
@@ -250,6 +266,11 @@ func runRun(opts *RunOptions) error {
 		return err
 	}
 
+	if opts.Detector == nil {
+		cachedClient := api.NewCachedHTTPClient(c, time.Hour*24)
+		opts.Detector = fd.NewDetector(cachedClient, repo.RepoHost())
+	}
+
 	ref := opts.Ref
 
 	if ref == "" {
@@ -293,34 +314,77 @@ func runRun(opts *RunOptions) error {
 		}
 	}
 
-	path := fmt.Sprintf("repos/%s/actions/workflows/%d/dispatches",
-		ghrepo.FullName(repo), workflow.ID)
+	features, err := opts.Detector.ActionsFeatures()
+	if err != nil {
+		return err
+	}
 
-	requestByte, err := json.Marshal(map[string]interface{}{
+	path := fmt.Sprintf("repos/%s/%s/actions/workflows/%d/dispatches", url.PathEscape(repo.RepoOwner()), url.PathEscape(repo.RepoName()), workflow.ID)
+
+	requestBody := map[string]interface{}{
 		"ref":    ref,
 		"inputs": providedInputs,
-	})
+	}
+
+	// TODO workflowDispatchRunDetailsCleanup
+	// We will have to always set the `return_run_details` field to true, unless
+	// we opt into the the new REST API version, which will probably return the
+	// details by default.
+	if features.DispatchRunDetails {
+		requestBody["return_run_details"] = true
+	}
+
+	requestByte, err := json.Marshal(requestBody)
 	if err != nil {
 		return fmt.Errorf("failed to serialize workflow inputs: %w", err)
 	}
 
 	body := bytes.NewReader(requestByte)
 
-	err = client.REST(repo.RepoHost(), "POST", path, body, nil)
+	var response struct {
+		WorkflowRunID int64  `json:"workflow_run_id"`
+		RunURL        string `json:"run_url"`
+		HtmlURL       string `json:"html_url"`
+	}
+
+	// Note that the workflow dispatch endpoint used to return 204 No Content
+	// (with no body, obviously). Now it's possible for the endpoint to also
+	// return 200 OK with created run details. So, we have to handle both cases
+	// because old GHE versions still return 204. Even on github.com, we
+	// may still get 204 for any reason.
+	//
+	// Our REST client library is smart enough to ignore JSON unmarshal when it
+	// receives 204, so we're safe here anyway.
+	//
+	// As a related note, the new REST API version (which will come with breaking
+	// changes) will probably default to return 200 + run details.
+	err = client.REST(repo.RepoHost(), "POST", path, body, &response)
 	if err != nil {
 		return fmt.Errorf("could not create workflow dispatch event: %w", err)
 	}
 
 	if opts.IO.IsStdoutTTY() {
-		out := opts.IO.Out
 		cs := opts.IO.ColorScheme()
-		fmt.Fprintf(out, "%s Created workflow_dispatch event for %s at %s\n",
+		fmt.Fprintf(opts.IO.Out, "%s Created workflow_dispatch event for %s at %s\n",
 			cs.SuccessIcon(), cs.Cyan(workflow.Base()), cs.Bold(ref))
 
-		fmt.Fprintln(out)
+		if response.HtmlURL != "" {
+			fmt.Fprintln(opts.IO.Out, response.HtmlURL)
+		}
 
-		fmt.Fprintf(out, "To see runs for this workflow, try: %s\n",
-			cs.Boldf("gh run list --workflow=%s", workflow.Base()))
+		fmt.Fprintln(opts.IO.Out)
+
+		if response.WorkflowRunID != 0 {
+			fmt.Fprintf(opts.IO.Out, "To see the created workflow run, try: %s\n",
+				cs.Boldf("gh run view %d", response.WorkflowRunID))
+		}
+
+		fmt.Fprintf(opts.IO.Out, "To see runs for this workflow, try: %s\n",
+			cs.Boldf("gh run list --workflow=%q", workflow.Base()))
+	} else {
+		if response.HtmlURL != "" {
+			fmt.Fprintln(opts.IO.Out, response.HtmlURL)
+		}
 	}
 
 	return nil
@@ -331,6 +395,8 @@ type WorkflowInput struct {
 	Required    bool
 	Default     string
 	Description string
+	Type        string
+	Options     []string
 }
 
 func findInputs(yamlContent []byte) ([]WorkflowInput, error) {
@@ -412,11 +478,16 @@ func findInputs(yamlContent []byte) ([]WorkflowInput, error) {
 	}
 
 	for name, input := range m {
+		if input.Type == "choice" && len(input.Options) == 0 {
+			return nil, fmt.Errorf("workflow input %q is of type choice, but has no options", name)
+		}
 		out = append(out, WorkflowInput{
 			Name:        name,
 			Default:     input.Default,
 			Description: input.Description,
 			Required:    input.Required,
+			Options:     input.Options,
+			Type:        input.Type,
 		})
 	}
 
